"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const config_1 = require("./src/config");
const querystring_1 = __importDefault(require("querystring"));
const underscore_1 = __importDefault(require("underscore"));
let config;
async function createTournament(oldTournamentData) {
    const oldData = underscore_1.default.clone(oldTournamentData);
    delete oldData.url;
    oldData.name = config.targetTournamentName;
    const { data } = await axios_1.default.post(" https://api.challonge.com/v1/tournaments.json", {
        api_key: config.apiKey,
        tournament: oldData,
    }, {
        validateStatus: function (status) {
            return true;
        },
        ...config_1.axiosPostConfig
    });
    console.log(data);
    config.targetTournament = data.url;
    await (0, config_1.writeConfig)(config);
    return config.targetTournament;
}
async function main() {
    config = await (0, config_1.loadConfig)();
    try {
        console.log(`Reading tournament ${config.sourceTournament}`);
        const { data: { tournament } } = await axios_1.default.get(` https://api.challonge.com/v1/tournaments/${config.sourceTournament}.json`, {
            responseType: "json",
            paramsSerializer: querystring_1.default.stringify,
            params: {
                api_key: config.apiKey,
                include_participants: 1
            },
        });
        if (!config.targetTournament) {
            console.log(`Target tournament does not exist. Creating one.`);
            const newTournamentUrl = await createTournament(tournament);
            console.log(`Tournament ${newTournamentUrl} created.`);
        }
        const oldParticipantDatas = tournament.participants;
        const oldParticipants = oldParticipantDatas.map(oldp => oldp.participant);
        console.log(`Creating participants.`);
        await axios_1.default.post(`https://api.challonge.com/v1/tournaments/${config.targetTournament}/participants/bulk_add.json`, {
            api_key: config.apiKey,
            participants: oldParticipants.map(p => ({ name: p.name, seed: p.seed })),
        }, config_1.axiosPostConfig);
        console.log(`Starting tournament.`);
        await axios_1.default.post(`https://api.challonge.com/v1/tournaments/${config.targetTournament}/start.json`, {
            api_key: config.apiKey
        }, config_1.axiosPostConfig);
        console.log(`Finished.`);
    }
    catch (e) {
        console.error(`Request failed: ${e.toString()}`);
    }
}
main();
//# sourceMappingURL=create.js.map