import axios, { AxiosRequestConfig } from 'axios';
import {
  Config,
  loadConfig,
  ParticipantData,
  writeConfig,
  axiosPostConfig,
} from './src/config';
import qs from 'querystring';
import _ from 'lodash';

let config: Config;

async function createTournament(oldTournamentData: any) {
  const oldData = _.clone(oldTournamentData);
  delete oldData.url;
  oldData.name = config.targetTournamentName;
  const { data } = await axios.post(
    ' https://api.challonge.com/v1/tournaments.json',
    {
      api_key: config.apiKey,
      tournament: oldData,
    },
    {
      validateStatus: function (status) {
        return true;
      },
      ...axiosPostConfig,
    },
  );
  console.log(data);
  config.targetTournament = data.url;
  await writeConfig(config);
  return config.targetTournament;
}

async function main() {
  config = await loadConfig();
  try {
    console.log(`Reading tournament ${config.sourceTournament}`);
    const {
      data: { tournament },
    } = await axios.get(
      ` https://api.challonge.com/v1/tournaments/${config.sourceTournament}.json`,
      {
        responseType: 'json',
        paramsSerializer: qs.stringify,
        params: {
          api_key: config.apiKey,
          include_participants: 1,
        },
      },
    );
    if (!config.targetTournament) {
      console.log(`Target tournament does not exist. Creating one.`);
      const newTournamentUrl = await createTournament(tournament);
      console.log(`Tournament ${newTournamentUrl} created.`);
    }
    const oldParticipantDatas = tournament.participants as ParticipantData[];
    const oldParticipants = oldParticipantDatas.map((oldp) => oldp.participant);
    const participants = oldParticipants.map((p) => ({
      name: p.name,
      seed: p.seed,
    }));
    console.log(`Creating participants.`);
    for (const chunk of _.chunk(participants, config.addParticipantChunk || 10)) {
      await axios.post(`https://api.challonge.com/v1/tournaments/${config.targetTournament}/participants/bulk_add.json`, {
        api_key: config.apiKey,
        participants: chunk,
    }, axiosPostConfig);
    }
    console.log(`Starting tournament.`);
    await axios.post(
      `https://api.challonge.com/v1/tournaments/${config.targetTournament}/start.json`,
      {
        api_key: config.apiKey,
      },
      axiosPostConfig,
    );
    console.log(`Finished.`);
  } catch (e) {
    console.error(`Request failed: ${e.toString()}`);
  }
}
main();
