import yaml from 'yaml';
import fs from 'fs';
import { AxiosRequestConfig } from 'axios';

export interface Config {
  apiKey: string;
  sourceTournament: string;
  targetTournament: string;
  targetTournamentName: string;
  maxRounds: number;
  addParticipantChunk: number;
}

export interface Participant {
  id: number;
  name: string;
  seed: number;
  active: boolean;
}

export interface ParticipantData {
  participant: Participant;
}

export interface Match {
  id: number;
  player1_id: number;
  player2_id: number;
  scores_csv: string;
  winner_id: string | number;
  state: string;
  round: number;
}

export interface MatchData {
  match: Match;
}

export const axiosPostConfig: AxiosRequestConfig = {
  responseType: 'json',
  headers: {
    'Content-Type': 'application/json;charset=utf-8',
  },
};

export async function loadConfig(): Promise<Config> {
  return yaml.parse(await fs.promises.readFile('./config.yaml', 'utf-8'));
}

export async function writeConfig(config: Config) {
  await fs.promises.writeFile('./config.yaml', yaml.stringify(config));
}
